==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Image/Gui/Resources/translations/Image_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Crea un piano immagine...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Create a planar image in the 3D space</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>crea un'immagine piana nello spazio 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Apri...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Apri il visualizzatore di immagini</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+308"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Tipo di spazio colore indefinito per la visualizzazione delle immagini</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Formato pixel</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Adatta immagine</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Stira l'immagine per adattarsi alla vista</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>Scala &amp;1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Visualizza l'immagine in scala 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>Colori &amp;originali</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Visualizza l'immagine con i suoi colori originali</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Colori più luminosi</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Visualizza l'immagine con colori più luminosi</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Pronto...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>grigio</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>fuori dall'immagine</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Visualizzatore di immagini</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Immagini (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Seleziona un file immagine da aprire</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>All files</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Errore durante l'apertura dell'immagine</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Impossibile caricare l'immagine scelta</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1+dfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Crea un piano immagine...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Crea un'immagine planare nello spazio 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>crea un'immagine piana nello spazio 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Apri...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Apri il visualizzatore di immagini</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Scala...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Ridimensionamento dell'immagine</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Spazio colore indefinito per la visualizzazione delle immagini</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Formato pixel</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Orientamento</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Piano dell'immagine</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Piano XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>Piano XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>Piano YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Direzione inversa</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Adatta immagine</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Stira l'immagine per adattarla alla vista</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Scala &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Visualizza l'immagine in scala 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>Colori &amp;originali</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Visualizza l'immagine con i suoi colori originali</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Colori più luminosi</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Visualizza l'immagine con colori più luminosi</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Pronto...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grigio</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>fuori dall'immagine</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Visualizzatore di immagini</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Immagini (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Seleziona un file immagine da aprire</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Immagini</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Tutti i file</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Errore durante l'apertura dell'immagine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Impossibile caricare l'immagine scelta</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Errore durante l'apertura dell'immagine</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Impossibile caricare l'immagine scelta</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
  </context>
</TS>
